---
name: Bug report
about: Report a bug you have encountered
title: ''
labels: type/bug
assignees: ''

---

<!-- Before raising an issue, it is suggested that you first check out the: -->

- [ ] [AiiDA Troubleshooting Documentation](https://aiida.readthedocs.io/projects/aiida-core/en/latest/intro/troubleshooting.html)
- [ ] [AiiDA Discourse Forum](https://aiida.discourse.group/)

### Describe the bug

<!-- A clear and concise description of what the bug is. -->

### Steps to reproduce

Steps to reproduce the behavior:

1. Go to '...'
2. Click on '....'
3. Scroll down to '....'
4. See error

### Expected behavior

<!-- A clear and concise description of what you expected to happen. -->

### Your environment

- Operating system [e.g. Linux]:
- Python version [e.g. 3.7.1]:
- aiida-core version [e.g. 1.2.1]:

Other relevant software versions, e.g. Postres & RabbitMQ

### Additional context

<!-- Add any other context about the problem here. -->
